@@ -7,7 +7,6 @@ import (
 	"context"
 
 	"github.com/derailed/popeye/internal"
-	"github.com/derailed/popeye/pkg/config"
 	"github.com/derailed/popeye/types"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -20,14 +19,6 @@ func mustExtractFactory(ctx context.Context) types.Factory {
 	return f
 }
 
-func mustExtractConfig(ctx context.Context) *config.Config {
-	cfg, ok := ctx.Value(internal.KeyConfig).(*config.Config)
-	if !ok {
-		panic("expecting config in context")
-	}
-	return cfg
-}
-
 // MetaFQN returns a full qualified ns/name string.
 func metaFQN(m metav1.ObjectMeta) string {
 	if m.Namespace == "" {
